@@ -103,11 +103,10 @@ class CategoriesEditorPage(Adw.NavigationPage):
 
         db_conn = create_db_connection()
         records = db_conn.execute('SELECT * FROM categories ORDER BY label ASC').fetchall()
-        db_conn.close()
 
         if records:
             for record in records:
-                category = Category.get(record['id'])
+                category = Category.get(record['id'], db_conn=db_conn)
 
                 row = CategoryRow(category)
                 row.delete_button.connect('clicked', self.delete_category, row)
@@ -120,6 +119,8 @@ class CategoriesEditorPage(Adw.NavigationPage):
         else:
             self.stack.set_visible_child_name('empty')
 
+        db_conn.close()
+
     def show(self):
         self.populate()
 
@@ -192,7 +193,7 @@ class CategoryRow(Gtk.ListBoxRow):
         self.cancel_button.connect('clicked', self.set_edit_mode, False)
         self.box.append(self.cancel_button)
 
-        self.save_button = Gtk.Button.new_from_icon_name('emblem-ok-symbolic')
+        self.save_button = Gtk.Button.new_from_icon_name('checkmark-symbolic')
         self.save_button.set_tooltip_text(_('Save'))
         self.save_button.set_valign(Gtk.Align.CENTER)
         self.save_button.add_css_class('suggested-action')
