@@ -48,14 +48,17 @@ class PreferencesDialog(Adw.PreferencesDialog):
     long_strip_detection_switch = Gtk.Template.Child('long_strip_detection_switch')
 
     reading_mode_row = Gtk.Template.Child('reading_mode_row')
-    clamp_size_adjustment = Gtk.Template.Child('clamp_size_adjustment')
-    scaling_row = Gtk.Template.Child('scaling_row')
     scaling_filter_row = Gtk.Template.Child('scaling_filter_row')
-    landscape_zoom_switch = Gtk.Template.Child('landscape_zoom_switch')
     background_color_row = Gtk.Template.Child('background_color_row')
-    borders_crop_switch = Gtk.Template.Child('borders_crop_switch')
     page_numbering_switch = Gtk.Template.Child('page_numbering_switch')
     fullscreen_switch = Gtk.Template.Child('fullscreen_switch')
+    scaling_row = Gtk.Template.Child('scaling_row')
+    landscape_zoom_switch = Gtk.Template.Child('landscape_zoom_switch')
+    borders_crop_switch = Gtk.Template.Child('borders_crop_switch')
+    webtoon_reading_mode_group_reset_button = Gtk.Template.Child('webtoon_reading_mode_group_reset_button')
+    clamp_size_adjustment = Gtk.Template.Child('clamp_size_adjustment')
+    scroll_click_percentage_adjustment = Gtk.Template.Child('scroll_click_percentage_adjustment')
+    scroll_drag_factor_adjustment = Gtk.Template.Child('scroll_drag_factor_adjustment')
 
     advanced_banner = Gtk.Template.Child('advanced_banner')
     clear_cached_data_actionrow = Gtk.Template.Child('clear_cached_data_actionrow')
@@ -162,8 +165,13 @@ class PreferencesDialog(Adw.PreferencesDialog):
         # Clear WebView data
 
         def confirm_callback():
-            self.window.webview.clear_data()
-            self.update_webview_data_size()
+            self.window.webview.clear_data(on_clear_data_finished)
+
+        def on_clear_data_finished(success):
+            if success:
+                self.update_webview_data_size()
+            else:
+                self.add_toast(Adw.Toast.new(_('Failed to clear WebView data')))
 
         self.window.open_dialog(
             _('Clear?'),
@@ -305,6 +313,12 @@ class PreferencesDialog(Adw.PreferencesDialog):
         elif index == 1:
             self.settings.scaling_filter = 'trilinear'
 
+    def on_scroll_click_percentage_changed(self, adjustment):
+        self.settings.scroll_click_percentage = adjustment.get_value()
+
+    def on_scroll_drag_factor_changed(self, adjustment):
+        self.settings.scroll_drag_factor = adjustment.get_value()
+
     def on_system_accent_colors_changed(self, switch_button, _gparam):
         self.settings.system_accent_colors = switch_button.get_active()
 
@@ -319,6 +333,17 @@ class PreferencesDialog(Adw.PreferencesDialog):
         else:
             self.settings.update_at_startup = False
 
+    def reset_webtoon_reading_mode_settings(self, _btn):
+        self.clamp_size_adjustment.set_value(
+            self.settings.get_default_value('clamp-size').get_int32()
+        )
+        self.scroll_click_percentage_adjustment.set_value(
+            self.settings.get_default_value('scroll-click-percentage').get_double()
+        )
+        self.scroll_drag_factor_adjustment.set_value(
+            self.settings.get_default_value('scroll-drag-factor').get_double()
+        )
+
     def set_config_values(self):
         #
         # General
@@ -418,30 +443,14 @@ class PreferencesDialog(Adw.PreferencesDialog):
         self.reading_mode_row.set_selected(self.settings.reading_mode_value)
         self.reading_mode_row.connect('notify::selected', self.on_reading_mode_changed)
 
-        # Pager clamp size ('Webtoon' reading mode only)
-        self.clamp_size_adjustment.set_value(self.settings.clamp_size)
-        self.clamp_size_adjustment.connect('value-changed', self.on_clamp_size_changed)
-
-        # Image scaling
-        self.scaling_row.set_selected(self.settings.scaling_value)
-        self.scaling_row.connect('notify::selected', self.on_scaling_changed)
-
         # Image scaling filter
         self.scaling_filter_row.set_selected(self.settings.scaling_filter_value)
         self.scaling_filter_row.connect('notify::selected', self.on_scaling_filter_changed)
 
-        # Landscape pages zoom ('LTR/RTL/Vertical' reading modes with 'Adapt to Screen' scaling only)
-        self.landscape_zoom_switch.set_active(self.settings.landscape_zoom)
-        self.landscape_zoom_switch.connect('notify::active', self.on_landscape_zoom_changed)
-
         # Background color
         self.background_color_row.set_selected(self.settings.background_color_value)
         self.background_color_row.connect('notify::selected', self.on_background_color_changed)
 
-        # Borders crop
-        self.borders_crop_switch.set_active(self.settings.borders_crop)
-        self.borders_crop_switch.connect('notify::active', self.on_borders_crop_changed)
-
         # Page numbering
         self.page_numbering_switch.set_active(not self.settings.page_numbering)
         self.page_numbering_switch.connect('notify::active', self.on_page_numbering_changed)
@@ -450,6 +459,37 @@ class PreferencesDialog(Adw.PreferencesDialog):
         self.fullscreen_switch.set_active(self.settings.fullscreen)
         self.fullscreen_switch.connect('notify::active', self.on_fullscreen_changed)
 
+        #
+        # Paged reading modes specific settings
+        # Image scaling
+        self.scaling_row.set_selected(self.settings.scaling_value)
+        self.scaling_row.connect('notify::selected', self.on_scaling_changed)
+
+        # Landscape pages zoom
+        self.landscape_zoom_switch.set_active(self.settings.landscape_zoom)
+        self.landscape_zoom_switch.connect('notify::active', self.on_landscape_zoom_changed)
+
+        # Borders crop
+        self.borders_crop_switch.set_active(self.settings.borders_crop)
+        self.borders_crop_switch.connect('notify::active', self.on_borders_crop_changed)
+
+        #
+        # Webtoon reading mode specific settings
+        # Reset button
+        self.webtoon_reading_mode_group_reset_button.connect('clicked', self.reset_webtoon_reading_mode_settings)
+
+        # Pager clamp size
+        self.clamp_size_adjustment.set_value(self.settings.clamp_size)
+        self.clamp_size_adjustment.connect('value-changed', self.on_clamp_size_changed)
+
+        # Scroll click percentage
+        self.scroll_click_percentage_adjustment.set_value(self.settings.scroll_click_percentage)
+        self.scroll_click_percentage_adjustment.connect('value-changed', self.on_scroll_click_percentage_changed)
+
+        # Scroll drag factor
+        self.scroll_drag_factor_adjustment.set_value(self.settings.scroll_drag_factor)
+        self.scroll_drag_factor_adjustment.connect('value-changed', self.on_scroll_drag_factor_changed)
+
         #
         # Advanced
         #
@@ -498,4 +538,4 @@ class PreferencesDialog(Adw.PreferencesDialog):
 
     def update_webview_data_size(self):
         size = folder_size(get_webview_data_dir(), exclude='cookies.sqlite')
-        self.clear_webview_data_actionrow.set_subtitle(size)
+        self.clear_webview_data_actionrow.set_subtitle(size or '-')
