@@ -7,12 +7,13 @@
 # Hachirumi [EN]
 # Magical Translators [EN/PL]
 
-from bs4 import BeautifulSoup
 import datetime
+
+from bs4 import BeautifulSoup
 import requests
 
+from komikku.consts import USER_AGENT
 from komikku.servers import Server
-from komikku.servers import USER_AGENT
 from komikku.utils import get_buffer_mime_type
 
 
